@@ -1,6 +1,4 @@
-pub mod add;
 pub mod list;
 pub mod profile;
 pub mod remove;
 pub mod switch;
-pub mod upgrade;
